aboutsummaryrefslogtreecommitdiff
path: root/projects/Notepad++
diff options
context:
space:
mode:
authorRay <raysan5@gmail.com>2018-07-15 23:19:06 +0200
committerRay <raysan5@gmail.com>2018-07-15 23:19:06 +0200
commitd127d8e9f8492dc29f6671c0a5bc51f26879f29a (patch)
tree052dda7d3bcacdc4de2f88174475c3fb4499e0ef /projects/Notepad++
parent0c631e6b5a917f2d94669d91750e93ac8c960a0d (diff)
downloadraylib-d127d8e9f8492dc29f6671c0a5bc51f26879f29a.tar.gz
raylib-d127d8e9f8492dc29f6671c0a5bc51f26879f29a.zip
Updated Notepad++ raylib intellisense
Diffstat (limited to 'projects/Notepad++')
-rw-r--r--projects/Notepad++/c_raylib.xml56
-rw-r--r--projects/Notepad++/raylib_npp_parser/raylib_npp.xml56
-rw-r--r--projects/Notepad++/raylib_npp_parser/raylib_to_parse.h31
3 files changed, 125 insertions, 18 deletions
diff --git a/projects/Notepad++/c_raylib.xml b/projects/Notepad++/c_raylib.xml
index 4ad11410..ee1c5f4b 100644
--- a/projects/Notepad++/c_raylib.xml
+++ b/projects/Notepad++/c_raylib.xml
@@ -846,6 +846,11 @@
<Param name="Image image" />
</Overload>
</KeyWord>
+ <KeyWord name="GetImageDataNormalized" func="yes">
+ <Overload retVal="Vector4" descr="Get pixel data from image as Vector4 array (float normalized)">
+ <Param name="Image image" />
+ </Overload>
+ </KeyWord>
<KeyWord name="GetPixelDataSize" func="yes">
<Overload retVal="int" descr="Get pixel data size in bytes (image or texture)">
<Param name="int width" />
@@ -927,6 +932,16 @@
<Param name="int newHeight" />
</Overload>
</KeyWord>
+ <KeyWord name="ImageResizeCanvas" func="yes">
+ <Overload retVal="void" descr="Resize canvas and fill with color">
+ <Param name="Image *image" />
+ <Param name="int newWidth" />
+ <Param name="int newHeight" />
+ <Param name="int offsetX" />
+ <Param name="int offsetY" />
+ <Param name="Color color" />
+ </Overload>
+ </KeyWord>
<KeyWord name="ImageMipmaps" func="yes">
<Overload retVal="void" descr="Generate all mipmap levels for a provided image">
<Param name="Image *image" />
@@ -1003,6 +1018,16 @@
<Param name="Image *image" />
</Overload>
</KeyWord>
+ <KeyWord name="ImageRotateCW" func="yes">
+ <Overload retVal="void" descr="Rotate image clockwise 90deg">
+ <Param name="Image *image" />
+ </Overload>
+ </KeyWord>
+ <KeyWord name="ImageRotateCCW" func="yes">
+ <Overload retVal="void" descr="Rotate image counter-clockwise 90deg">
+ <Param name="Image *image" />
+ </Overload>
+ </KeyWord>
<KeyWord name="ImageColorTint" func="yes">
<Overload retVal="void" descr="Modify image color: tint">
<Param name="Image *image" />
@@ -1031,6 +1056,13 @@
<Param name="int brightness" />
</Overload>
</KeyWord>
+ <KeyWord name="ImageColorReplace" func="yes">
+ <Overload retVal="void" descr="Modify image color: replace color">
+ <Param name="Image *image" />
+ <Param name="Color color" />
+ <Param name="Color replace" />
+ </Overload>
+ </KeyWord>
<!-- Image generation functions -->
<KeyWord name="GenImageColor" func="yes">
@@ -1167,22 +1199,40 @@
<!-------------------------------------------------------------------------------------- -->
<!-- Font loading/unloading functions -->
- <KeyWord name="GetDefaultFont" func="yes">
+ <KeyWord name="GetFontDefault" func="yes">
<Overload retVal="Font" descr="Get the default Font"></Overload>
</KeyWord>
<KeyWord name="LoadFont" func="yes">
- <Overload retVal="Font" descr="Load Font from file into GPU memory (VRAM)">
+ <Overload retVal="Font" descr="Load font from file into GPU memory (VRAM)">
<Param name="const char *fileName" />
</Overload>
</KeyWord>
<KeyWord name="LoadFontEx" func="yes">
- <Overload retVal="Font" descr="Load Font from file with extended parameters">
+ <Overload retVal="Font" descr="Load font from file with extended parameters">
<Param name="const char *fileName" />
<Param name="int fontSize" />
<Param name="int charsCount" />
<Param name="int *fontChars" />
</Overload>
</KeyWord>
+ <KeyWord name="LoadFontData" func="yes">
+ <Overload retVal="CharInfo" descr="Load font data for further use">
+ <Param name="const char *fileName" />
+ <Param name="int fontSize" />
+ <Param name="int *fontChars" />
+ <Param name="int charsCount" />
+ <Param name="bool sdf" />
+ </Overload>
+ </KeyWord>
+ <KeyWord name="GenImageFontAtlas" func="yes">
+ <Overload retVal="Image" descr="Generate image font atlas using chars info">
+ <Param name="CharInfo *chars" />
+ <Param name="int fontSize" />
+ <Param name="int charsCount" />
+ <Param name="int padding" />
+ <Param name="int packMethod" />
+ </Overload>
+ </KeyWord>
<KeyWord name="UnloadFont" func="yes">
<Overload retVal="void" descr="Unload Font from GPU memory (VRAM)">
<Param name="Font font" />
diff --git a/projects/Notepad++/raylib_npp_parser/raylib_npp.xml b/projects/Notepad++/raylib_npp_parser/raylib_npp.xml
index 8144c8fb..e3952538 100644
--- a/projects/Notepad++/raylib_npp_parser/raylib_npp.xml
+++ b/projects/Notepad++/raylib_npp_parser/raylib_npp.xml
@@ -811,6 +811,11 @@
<Param name="Image image" />
</Overload>
</KeyWord>
+ <KeyWord name="GetImageDataNormalized" func="yes">
+ <Overload retVal="Vector4" descr="Get pixel data from image as Vector4 array (float normalized)">
+ <Param name="Image image" />
+ </Overload>
+ </KeyWord>
<KeyWord name="GetPixelDataSize" func="yes">
<Overload retVal="int" descr="Get pixel data size in bytes (image or texture)">
<Param name="int width" />
@@ -892,6 +897,16 @@
<Param name="int newHeight" />
</Overload>
</KeyWord>
+ <KeyWord name="ImageResizeCanvas" func="yes">
+ <Overload retVal="void" descr="Resize canvas and fill with color">
+ <Param name="Image *image" />
+ <Param name="int newWidth" />
+ <Param name="int newHeight" />
+ <Param name="int offsetX" />
+ <Param name="int offsetY" />
+ <Param name="Color color" />
+ </Overload>
+ </KeyWord>
<KeyWord name="ImageMipmaps" func="yes">
<Overload retVal="void" descr="Generate all mipmap levels for a provided image">
<Param name="Image *image" />
@@ -968,6 +983,16 @@
<Param name="Image *image" />
</Overload>
</KeyWord>
+ <KeyWord name="ImageRotateCW" func="yes">
+ <Overload retVal="void" descr="Rotate image clockwise 90deg">
+ <Param name="Image *image" />
+ </Overload>
+ </KeyWord>
+ <KeyWord name="ImageRotateCCW" func="yes">
+ <Overload retVal="void" descr="Rotate image counter-clockwise 90deg">
+ <Param name="Image *image" />
+ </Overload>
+ </KeyWord>
<KeyWord name="ImageColorTint" func="yes">
<Overload retVal="void" descr="Modify image color: tint">
<Param name="Image *image" />
@@ -996,6 +1021,13 @@
<Param name="int brightness" />
</Overload>
</KeyWord>
+ <KeyWord name="ImageColorReplace" func="yes">
+ <Overload retVal="void" descr="Modify image color: replace color">
+ <Param name="Image *image" />
+ <Param name="Color color" />
+ <Param name="Color replace" />
+ </Overload>
+ </KeyWord>
<!-- Image generation functions -->
<KeyWord name="GenImageColor" func="yes">
@@ -1132,22 +1164,40 @@
<!-------------------------------------------------------------------------------------- -->
<!-- Font loading/unloading functions -->
- <KeyWord name="GetDefaultFont" func="yes">
+ <KeyWord name="GetFontDefault" func="yes">
<Overload retVal="Font" descr="Get the default Font"></Overload>
</KeyWord>
<KeyWord name="LoadFont" func="yes">
- <Overload retVal="Font" descr="Load Font from file into GPU memory (VRAM)">
+ <Overload retVal="Font" descr="Load font from file into GPU memory (VRAM)">
<Param name="const char *fileName" />
</Overload>
</KeyWord>
<KeyWord name="LoadFontEx" func="yes">
- <Overload retVal="Font" descr="Load Font from file with extended parameters">
+ <Overload retVal="Font" descr="Load font from file with extended parameters">
<Param name="const char *fileName" />
<Param name="int fontSize" />
<Param name="int charsCount" />
<Param name="int *fontChars" />
</Overload>
</KeyWord>
+ <KeyWord name="LoadFontData" func="yes">
+ <Overload retVal="CharInfo" descr="Load font data for further use">
+ <Param name="const char *fileName" />
+ <Param name="int fontSize" />
+ <Param name="int *fontChars" />
+ <Param name="int charsCount" />
+ <Param name="bool sdf" />
+ </Overload>
+ </KeyWord>
+ <KeyWord name="GenImageFontAtlas" func="yes">
+ <Overload retVal="Image" descr="Generate image font atlas using chars info">
+ <Param name="CharInfo *chars" />
+ <Param name="int fontSize" />
+ <Param name="int charsCount" />
+ <Param name="int padding" />
+ <Param name="int packMethod" />
+ </Overload>
+ </KeyWord>
<KeyWord name="UnloadFont" func="yes">
<Overload retVal="void" descr="Unload Font from GPU memory (VRAM)">
<Param name="Font font" />
diff --git a/projects/Notepad++/raylib_npp_parser/raylib_to_parse.h b/projects/Notepad++/raylib_npp_parser/raylib_to_parse.h
index 004faeaf..0f3c3a69 100644
--- a/projects/Notepad++/raylib_npp_parser/raylib_to_parse.h
+++ b/projects/Notepad++/raylib_npp_parser/raylib_to_parse.h
@@ -198,6 +198,7 @@ RLAPI void UnloadImage(Image image);
RLAPI void UnloadTexture(Texture2D texture); // Unload texture from GPU memory (VRAM)
RLAPI void UnloadRenderTexture(RenderTexture2D target); // Unload render texture from GPU memory (VRAM)
RLAPI Color *GetImageData(Image image); // Get pixel data from image as a Color struct array
+RLAPI Vector4 *GetImageDataNormalized(Image image); // Get pixel data from image as Vector4 array (float normalized)
RLAPI int GetPixelDataSize(int width, int height, int format); // Get pixel data size in bytes (image or texture)
RLAPI Image GetTextureData(Texture2D texture); // Get pixel data from GPU texture and return an Image
RLAPI void UpdateTexture(Texture2D texture, const void *pixels); // Update GPU texture with new data
@@ -213,21 +214,25 @@ RLAPI void ImageAlphaPremultiply(Image *image);
RLAPI void ImageCrop(Image *image, Rectangle crop); // Crop an image to a defined rectangle
RLAPI void ImageResize(Image *image, int newWidth, int newHeight); // Resize and image (bilinear filtering)
RLAPI void ImageResizeNN(Image *image,int newWidth,int newHeight); // Resize and image (Nearest-Neighbor scaling algorithm)
+RLAPI void ImageResizeCanvas(Image *image, int newWidth, int newHeight, int offsetX, int offsetY, Color color); // Resize canvas and fill with color
RLAPI void ImageMipmaps(Image *image); // Generate all mipmap levels for a provided image
RLAPI void ImageDither(Image *image, int rBpp, int gBpp, int bBpp, int aBpp); // Dither image data to 16bpp or lower (Floyd-Steinberg dithering)
RLAPI Image ImageText(const char *text, int fontSize, Color color); // Create an image from text (default font)
-RLAPI Image ImageTextEx(Font font, const char *text, float fontSize, float spacing, Color tint); // Create an image from text (custom sprite font)
+RLAPI Image ImageTextEx(Font font, const char *text, float fontSize, float spacing, Color tint); // Create an image from text (custom sprite font)
RLAPI void ImageDraw(Image *dst, Image src, Rectangle srcRec, Rectangle dstRec); // Draw a source image within a destination image
RLAPI void ImageDrawRectangle(Image *dst, Vector2 position, Rectangle rec, Color color); // Draw rectangle within an image
RLAPI void ImageDrawText(Image *dst, Vector2 position, const char *text, int fontSize, Color color); // Draw text (default font) within an image (destination)
RLAPI void ImageDrawTextEx(Image *dst, Vector2 position, Font font, const char *text, float fontSize, float spacing, Color color); // Draw text (custom sprite font) within an image (destination)
RLAPI void ImageFlipVertical(Image *image); // Flip image vertically
RLAPI void ImageFlipHorizontal(Image *image); // Flip image horizontally
+RLAPI void ImageRotateCW(Image *image); // Rotate image clockwise 90deg
+RLAPI void ImageRotateCCW(Image *image); // Rotate image counter-clockwise 90deg
RLAPI void ImageColorTint(Image *image, Color color); // Modify image color: tint
RLAPI void ImageColorInvert(Image *image); // Modify image color: invert
RLAPI void ImageColorGrayscale(Image *image); // Modify image color: grayscale
RLAPI void ImageColorContrast(Image *image, float contrast); // Modify image color: contrast (-100 to 100)
RLAPI void ImageColorBrightness(Image *image, int brightness); // Modify image color: brightness (-255 to 255)
+RLAPI void ImageColorReplace(Image *image, Color color, Color replace); // Modify image color: replace color
// Image generation functions
RLAPI Image GenImageColor(int width, int height, Color color); // Generate image: plain color
@@ -257,22 +262,24 @@ RLAPI void DrawTexturePro(Texture2D texture, Rectangle sourceRec, Rectangle dest
//------------------------------------------------------------------------------------
// Font loading/unloading functions
-RLAPI Font GetDefaultFont(void); // Get the default Font
-RLAPI Font LoadFont(const char *fileName); // Load Font from file into GPU memory (VRAM)
-RLAPI Font LoadFontEx(const char *fileName, int fontSize, int charsCount, int *fontChars); // Load Font from file with extended parameters
-RLAPI void UnloadFont(Font font); // Unload Font from GPU memory (VRAM)
+RLAPI Font GetFontDefault(void); // Get the default Font
+RLAPI Font LoadFont(const char *fileName); // Load font from file into GPU memory (VRAM)
+RLAPI Font LoadFontEx(const char *fileName, int fontSize, int charsCount, int *fontChars); // Load font from file with extended parameters
+RLAPI CharInfo *LoadFontData(const char *fileName, int fontSize, int *fontChars, int charsCount, bool sdf); // Load font data for further use
+RLAPI Image GenImageFontAtlas(CharInfo *chars, int fontSize, int charsCount, int padding, int packMethod); // Generate image font atlas using chars info
+RLAPI void UnloadFont(Font font); // Unload Font from GPU memory (VRAM)
// Text drawing functions
-RLAPI void DrawFPS(int posX, int posY); // Shows current FPS
-RLAPI void DrawText(const char *text, int posX, int posY, int fontSize, Color color); // Draw text (using default font)
+RLAPI void DrawFPS(int posX, int posY); // Shows current FPS
+RLAPI void DrawText(const char *text, int posX, int posY, int fontSize, Color color); // Draw text (using default font)
RLAPI void DrawTextEx(Font font, const char* text, Vector2 position, float fontSize, float spacing, Color tint); // Draw text using Font and additional parameters
// Text misc. functions
-RLAPI int MeasureText(const char *text, int fontSize); // Measure string width for default font
-RLAPI Vector2 MeasureTextEx(Font font, const char *text, float fontSize, float spacing); // Measure string size for Font
-RLAPI const char *FormatText(const char *text, ...); // Formatting of text with variables to 'embed'
-RLAPI const char *SubText(const char *text, int position, int length); // Get a piece of a text string
-RLAPI int GetGlyphIndex(Font font, int character); // Returns index position for a unicode character on sprite font
+RLAPI int MeasureText(const char *text, int fontSize); // Measure string width for default font
+RLAPI Vector2 MeasureTextEx(Font font, const char *text, float fontSize, float spacing); // Measure string size for Font
+RLAPI const char *FormatText(const char *text, ...); // Formatting of text with variables to 'embed'
+RLAPI const char *SubText(const char *text, int position, int length); // Get a piece of a text string
+RLAPI int GetGlyphIndex(Font font, int character); // Returns index position for a unicode character on sprite font
//------------------------------------------------------------------------------------
// Basic 3d Shapes Drawing Functions (Module: models)